#
# spec file for package engauge-digitizer
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           engauge-digitizer
Version:        10.4
Release:        lp150.3.16
Summary:        Ditigize old graphs into numbers again
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Other
Url:            http://markummitchell.github.io/engauge-digitizer/
Source0:        https://github.com/markummitchell/%{name}/archive/v%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  icns-utils
BuildRequires:  optipng
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(log4cpp)
BuildRequires:  pkgconfig(poppler-qt5)
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
Suggests:       %{name}-doc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This open source, digitizing software converts an image
file showing a graph or map, into numbers. The image file can come
from a scanner, digital camera or screenshot. The numbers can be read
on the screen, and written or copied to a spreadsheet.

%package doc
Summary:        Documentation for Engauge Digitizer
Group:          Documentation/HTML
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
This package contains the documentation for Engauge Digitizer.

%package devel-doc
Summary:        Development documentation for Engauge Digitizer
Group:          Documentation/HTML
Requires:       %{name} = %{version}
BuildArch:      noarch

%description devel-doc
This package contains the development documentation for Engauge Digitizer.

%prep
%setup -q

%build
# ADD JPEG2000 SUPPORT
export OPENJPEG_INCLUDE=$(pkg-config --cflags-only-I libopenjp2 | sed -e 's@-I\(\S\+\).*@\1@g')
export OPENJPEG_LIB=%{_libdir}
export POPPLER_INCLUDE=%{_includedir}/poppler/qt5
export POPPLER_LIB=%{_libdir}

qmake-qt5 engauge.pro \
  "DEFINES+=HELPDIR=%{_docdir}/%{name}/" \
  QMAKE_CFLAGS="%optflags -fno-strict-aliasing" \
  QMAKE_CXXFLAGS="%optflags -fno-strict-aliasing" \
  CONFIG+="pdf jpeg2000"
make %{?_smp_mflags}

# HELP files
pushd help
# CRLF -> LF
sed -i 's/\r$//' engauge.qhcp dateformats.css dateformats.html
optipng -o2 *png
qcollectiongenerator-qt5 engauge.qhcp -o engauge.qhc
mv engauge.qch engauge.qhc ../
rm build build.mingw engauge.qhcp .gitignore
popd

# Generate source code documentation in HTML format
pushd src
sed -i 's/\(GENERATE_LATEX.*\)=.*/\1 = NO/' Doxyfile
doxygen
popd

%install
install -Dm 755 bin/engauge %{buildroot}%{_bindir}/engauge

# INSTALL HI-RES ICONS
pushd src/img
icns2png -x digitizer.icns
for sz in 16 32 128 256 512; do
  install -Dm 0644 digitizer_${sz}x${sz}x32.png %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps/%{name}.png
done
popd

%suse_update_desktop_file -i %{name}

# INSTALL APPDATA
install -Dm 0644 dev/gnome/engauge-digitizer.appdata.xml \
            %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%fdupes -s doc/doxygen/html

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc README.md engauge.qhc engauge.qch
%license LICENSE
%{_bindir}/engauge
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%files doc
%doc help

%files devel-doc
%doc doc/doxygen/html

%changelog
* Tue Mar 27 2018 stefan.bruens@rwth-aachen.de
- Fix build on Leap 42.x, remove space in OPENJPEG_INCLUDE
- Cleanup spec file/build
  + Do not build source documentation in PDF format, drop TeXlive
    BuildRequires
  + Move source documentation to devel-doc subpackage
  + Move standalone HTML user manual to doc subpackage
  + Fix path to QCH help files
  + Shrink documentation images using optipng
  + trivial cleanups
* Fri Mar  2 2018 crrodriguez@opensuse.org
- Reenable jpeg2000 support.
- Fix build requires, remove unused libjpeg-devel, libpng-devel
* Tue Oct 10 2017 badshah400@gmail.com
- Update to version 10.4:
  + Show warning message when grid line maximum is exceed
    (gh#markummitchell/engauge-digitizer#244).
  + CSV export files have double quotes on fields with internal
    commas (gh#markummitchell/engauge-digitizer#243).
  + Status bar shows all of text for right-to-left languages
    (gh#markummitchell/engauge-digitizer#240).
* Mon Aug 28 2017 badshah400@gmail.com
- Update to version 10.3:
  + Updated translations.
* Wed Aug 23 2017 badshah400@gmail.com
- Update to version 10.2:
  + More zoom levels for increased flexibility in zooming
    (gh#markummitchell/engauge-digitizer#237).
* Sat Jul 22 2017 badshah400@gmail.com
- Update to version 10.1:
  + Export settings dialog usability improvements
    (gh#markummitchell/engauge-digitizer#235).
  + Export files have blank line between sections
    (gh#markummitchell/engauge-digitizer#234).
  + Export setting for raw relation points is saved
    (gh#markummitchell/engauge-digitizer#229).
  + Four-axes axis point coordinates are not confused
    (gh#markummitchell/engauge-digitizer#228).
  + Newly copied points can be pasted
    (gh#markummitchell/engauge-digitizer#227).
  + Prevent crash if grid is undefined
    (gh#markummitchell/engauge-digitizer#226).
- Drop engauge-digitizer-license-fix.patch: upstreamed.
* Fri Jun  2 2017 badshah400@gmail.com
- Add engauge-digitizer-license-fix.patch: Remove ancient unwanted
  license info; patch taken from upstream git
  (gh#markummitchell/engauge-digitizer#230).
* Mon Apr 17 2017 badshah400@gmail.com
- Add BuildRequires on tex(xtab.sty) to fix build failure on
  openSUSE Leap 42.1 (this is automatically pulled in for Leap
  42.2 and higher, so having the BuildRequires unconditionally
  doesn't hurt).
* Thu Apr 13 2017 badshah400@gmail.com
- Update to version 10.0:
  * Maps with a scale bar are supported
    (gh#markummitchell/engauge-digitizer#208,
    gh#markummitchell/engauge-digitizer#224).
  * Include missing points during export of interpolated relation
    curves (gh#markummitchell/engauge-digitizer#222).
* Sat Jan  7 2017 badshah400@gmail.com
- Update to version 9.8:
  * Prevent false alarm from Windows antivirus software.
- Changes from version 9.7:
  * Installation help for users having problems installing in
    Fedora (gh#markummitchell/engauge-digitizer#203).
  * Functions with points sharing the same X coordinate no longer
    crash (gh#markummitchell/engauge-digitizer#202).
- Changes from version 9.6:
  * Time coordinates have full precision after being saved and
    loaded (gh#markummitchell/engauge-digitizer#201).
  * Points are still associated with their curves after curve
    names are reordered (gh#markummitchell/engauge-digitizer#200).
  * Fix Save As Default button in Curve Add/Remove dialog
    (gh#markummitchell/engauge-digitizer#199).
  * Clean up text for translations
    (gh#markummitchell/engauge-digitizer#198,
    gh#markummitchell/engauge-digitizer#197,
    gh#markummitchell/engauge-digitizer#188).
  * Export of log coordinates no longer produces illegal values
    (gh#markummitchell/engauge-digitizer#196).
* Sat Nov  5 2016 badshah400@gmail.com
- Update to version 9.5:
  * Tested segment fill and point match
    (gh#markummitchell/engauge-digitizer#189)
  * Fix when changing to log coordinates
    (gh#markummitchell/engauge-digitizer#182)
* Sun Oct  2 2016 badshah400@gmail.com
- Update to version 9.4:
  + Language translations for Russian, Portuguese, Spanish,
    French, German and Chinese.
  + Fixes for coordinate checking
    (gh#markummitchell/engauge-digitizer#182,
    gh#markummitchell/engauge-digitizer#189).
- Drop engauge-digitizer-desktop-file.patch: incorporated
  upstream.
- Drop README.md from the -doc subpkg, it is already packaged in
  main package.
* Fri Sep  2 2016 badshah400@gmail.com
- Drop external .desktop file and use the upstream file.
- Add engauge-digitizer-desktop-file.patch to:
  + Fix Categories according to openSUSE guidelines
  + Add a GenericName
  + Replace absolute icon file name by base name (to make use of
    hicolor icons)
  + Add trailing colon to MimeType entry.
* Fri Sep  2 2016 badshah400@gmail.com
- Update to version 9.3:
  + Fix crash in Settings / Main Window when pdf import support is
    not available (gh#markummitchell/engauge-digitizer#177).
  + Settings dialogs can be made very small to fit on small
    screens (gh#markummitchell/engauge-digitizer#176).
- Changes from version 9.2:
  + Apply extra digits of precision setting to export file
    (gh#markummitchell/engauge-digitizer#175).
  + Release fixes: gh#markummitchell/engauge-digitizer#174,
    gh#markummitchell/engauge-digitizer#173,
    gh#markummitchell/engauge-digitizer#172.
  + Zenodo citation (gh#markummitchell/engauge-digitizer#171).
* Sun Aug 21 2016 badshah400@gmail.com
- Update to version 9.1:
  + Fix crash if graph points are generated before axis points
    (gh#markummitchell/engauge-digitizer#167)
  + Default for import cropping brings up cropping window for
    multi-page pdfs (gh#markummitchell/engauge-digitizer#166)
- Changes from version 9.0:
  + Image cropping option on import extracts just the graphs from
    files with other image data
    (gh#markummitchell/engauge-digitizer#149)
  + Geometry window gives point feedback, and is another method
    for drag-and-drop export
    (gh#markummitchell/engauge-digitizer#143)
  + Image replace menu option for rapid transfer of settings to a
    new image (gh#markummitchell/engauge-digitizer#154)
  + Cursor restoration after editing of points
    (gh#markummitchell/engauge-digitizer#155)
  + Editing of graphics point coordinates for improved accuracy
    (gh#markummitchell/engauge-digitizer#156)
  + Prevent hang for certain combinations of grid settings
    (gh#markummitchell/engauge-digitizer#159)
  + Semicolon delimiter option added for export
    (gh#markummitchell/engauge-digitizer#161)
  + Settings reset option added to command line
    (gh#markummitchell/engauge-digitizer#162)
- Changes from version 8.3:
  + Pdf file import (gh#markummitchell/engauge-digitizer#133,
    gh#markummitchell/engauge-digitizer#143,
    gh#markummitchell/engauge-digitizer#147)
  + Extrapolation of points past the first and last points during
    export (gh#markummitchell/engauge-digitizer#137)
  + Fix crash on loading of new file after closing previous file
    (gh#markummitchell/engauge-digitizer#139)
  + Background image can be replaced for reusing axes and/or
    settings when a new image is like a past image
    (gh#markummitchell/engauge-digitizer#154)
- Packaging changes:
  + Add BuildRequires: pkgconfig(poppler-qt5) and enable building
    with pdf support (set POPPLER_INCLUDE and POPPLER_LIB env
    variables, CONFIG+=pdf to qmake).
  + Replace BuildRequires: pkgconfig(libjpeg) by libjpeg-devel to
    make package build for Leap.
  + Manually install doxygen HTML doc files instead of using the
    %%doc macro; this allows to cleanup duplicates using fdupes
    (add BuildRequires: fdupes).
  + Remove unneeded .gitignore file from help.
  + Correct EOF encodings using sed where appropriate.
  + Move license to main package.
* Thu Jun 30 2016 badshah400@gmail.com
- Update to version 8.2:
  + Sub-pixel point placement increases accuracy
  + Undo/redo makes recovering from mistakes easy
  + Easier and more powerful zooming
  + Improved drag-and-drop
  + Wizard provides an interactive tutorial to explain the basic
    steps
  + Wizard creates a checklist guide to interactively leads
    user through steps from file import to file export
  + See https://github.com/markummitchell/engauge-digitizer/releases
    for a full list of chages since previously packaged version.
- Packaging changes:
  + Drop doc-path.patch: No longer needed.
  + Build hires icons from bundled icns file and install them
    to the hicolor icon directory; drop addtional png icon file.
  + Build and install PDF and HTML documentation in-situ using
    doxygen as part of doc subpackage.
  + Building now depends on Qt5 libraries, update BuildRequires.
  + Build and install help files in main pkg.
  + Post and Postun scriptlets to update desktop database and
    hicolor icon theme cache.
  + Install bundled appdata file into appdata dir.
  + Add rpmlintrc file to suppress false positive warnings for
    file-contains-date-and-time in the doc package.
* Mon Mar 16 2015 sfalken@opensuse.org
- Changed desktop categories to Science;Math;DataVisualization; to
  clear brp-check-suse error
* Wed Jan  7 2015 p.drouand@gmail.com
- Update to version 5.2
  + No changelog available
- Upstream has renamed tarball for engauge
- Build with "%%{optflags} -fno-strict-aliasing"
* Thu Dec 27 2012 dmitry_r@opensuse.org
- Update to version 5.1
  * no changelog available
* Sun Dec  9 2012 dmitry_r@opensuse.org
- Update to git 2012.10.11
* Fri Aug 31 2012 scorot@free.fr
- fix debuginfo packaging failure on SLE 11
* Fri Aug 24 2012 dmitry_r@opensuse.org
- Update to version 5.0
